==> reconciliation-manage-domain-0.0.34-sources.jar: com/xforceplus/reconciliationbill/entity/ReconBill.java <==
package com.xforceplus.reconciliationbill.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-13
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ReconBill implements Serializable {

  private static final long serialVersionUID=1L;

  private Long salesbillId;

  private String salesbillNo;

  private String sellerNo;

  private String sellerName;

  private Long id;

  private Long tenantId;

  private String tenantCode;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String sellerTaxNo;

  private String sellerTel;

  private String sellerAddress;

  private String sellerBankName;

  private String sellerBankAccount;

  private Long sellerTenantId;

  private Long sellerId;

  private String purchaserNo;

  private String purchaserName;

  private String purchaserTaxNo;

  private String purchaserTel;

  private String purchaserAddress;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private Long purchaserTenantId;

  private Long purchaserId;

  private String businessBillType;

  private String systemOrig;

  private String salesbillType;

  private String receiptType;

  private String invoiceType;

  private Long priceMethod;

  private BigDecimal amountWithTax;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal abandonFreezeAmountWithTax;

  private BigDecimal abandonFreezeAmountWithoutTax;

  private BigDecimal abandonFreezeAmountTaxAmount;

  private BigDecimal discountWithTaxTotal;

  private BigDecimal discountWithoutTaxTotal;

  private BigDecimal discountTaxAmountTotal;

  private BigDecimal outterDiscountWithTax;

  private BigDecimal outterDiscountWithoutTax;

  private BigDecimal innerDiscountWithTax;

  private BigDecimal innerDiscountWithoutTax;

  private BigDecimal outterPrepayAmountWithTax;

  private BigDecimal outterPrepayAmountWithoutTax;

  private BigDecimal innerPrepayAmountWithTax;

  private BigDecimal innerPrepayAmountWithoutTax;

  private Long cooperateFlag;

  private String status;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String originInvoiceType;

  private String originPaperDrawDate;

  private String redNotification;

  private String checkerName;

  private String cashierName;

  private String invoicerName;

  private String receiveUserEmail;

  private String receiveUserTel;

  private Long sysOrgId;

  private Long deleteToken;

  private String customerNo;

  private String addressee;

  private String addresseeTel;

  private String addresseeProvince;

  private String addresseeCity;

  private String addresseeCounty;

  private String direction;

  private String logisticRemark;

  private String remark;

  private String ext1;

  private String ext2;

  private String ext3;

  private String ext4;

  private String ext5;

  private String ext6;

  private String ext7;

  private String ext8;

  private String ext9;

  private String ext10;

  private String ext11;

  private String ext12;

  private String ext13;

  private String ext14;

  private String ext15;

  private String ext16;

  private String ext17;

  private String ext18;

  private String ext19;

  private String ext20;

  private String ext21;

  private String ext22;

  private String ext23;

  private String ext24;

  private String ext25;

  private String lockFlag;




        }

==> reconciliation-manage-domain-0.0.37-sources.jar: com/xforceplus/reconciliationbill/entity/ReconBill.java <==
package com.xforceplus.reconciliationbill.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-30
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ReconBill implements Serializable {

  private static final long serialVersionUID=1L;

  private Long salesbillId;

  private String salesbillNo;

  private String sellerNo;

  private String sellerName;

  private Long id;

  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  @TableField(fill = FieldFill.INSERT)
  private LocalDateTime createTime;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private LocalDateTime updateTime;

  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  private String sellerTaxNo;

  private String sellerTel;

  private String sellerAddress;

  private String sellerBankName;

  private String sellerBankAccount;

  private Long sellerTenantId;

  private Long sellerId;

  private String purchaserNo;

  private String purchaserName;

  private String purchaserTaxNo;

  private String purchaserTel;

  private String purchaserAddress;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private Long purchaserTenantId;

  private Long purchaserId;

  private String businessBillType;

  private String systemOrig;

  private String salesbillType;

  private String receiptType;

  private String invoiceType;

  private Long priceMethod;

  private BigDecimal amountWithTax;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal abandonFreezeAmountWithTax;

  private BigDecimal abandonFreezeAmountWithoutTax;

  private BigDecimal abandonFreezeAmountTaxAmount;

  private BigDecimal discountWithTaxTotal;

  private BigDecimal discountWithoutTaxTotal;

  private BigDecimal discountTaxAmountTotal;

  private BigDecimal outterDiscountWithTax;

  private BigDecimal outterDiscountWithoutTax;

  private BigDecimal innerDiscountWithTax;

  private BigDecimal innerDiscountWithoutTax;

  private BigDecimal outterPrepayAmountWithTax;

  private BigDecimal outterPrepayAmountWithoutTax;

  private BigDecimal innerPrepayAmountWithTax;

  private BigDecimal innerPrepayAmountWithoutTax;

  private Long cooperateFlag;

  private String status;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String originInvoiceType;

  private String originPaperDrawDate;

  private String redNotification;

  private String checkerName;

  private String cashierName;

  private String invoicerName;

  private String receiveUserEmail;

  private String receiveUserTel;

  private Long sysOrgId;

  private Long deleteToken;

  private String customerNo;

  private String addressee;

  private String addresseeTel;

  private String addresseeProvince;

  private String addresseeCity;

  private String addresseeCounty;

  private String direction;

  private String logisticRemark;

  private String remark;

  private String ext1;

  private String ext2;

  private String ext3;

  private String ext4;

  private String ext5;

  private String ext6;

  private String ext7;

  private String ext8;

  private String ext9;

  private String ext10;

  private String ext11;

  private String ext12;

  private String ext13;

  private String ext14;

  private String ext15;

  private String ext16;

  private String ext17;

  private String ext18;

  private String ext19;

  private String ext20;

  private String ext21;

  private String ext22;

  private String ext23;

  private String ext24;

  private String ext25;

  private String lockFlag;




        }
